@@ -13,7 +13,8 @@ from types import MethodType
 from types import FunctionType
 
 from apivideo.api_client import ApiClient
-from apivideo.endpoint import EndPoint as _EndPoint
+from apivideo.endpoint import EndPoint as _EndPoint, ChunkIO
+from apivideo.model.video_id import VideoId
 from apivideo.model_utils import (  # noqa: F401
     check_allowed_values,
     check_validations,
@@ -49,7 +50,7 @@ class RawStatisticsApi(_EndPoint):
                 live_stream_id (str): The unique identifier for the live stream you want to retrieve analytics for.
 
             Keyword Args:
-                period (str): Period must have one of the following formats:  - For a day : \"2018-01-01\", - For a week: \"2018-W01\", - For a month: \"2018-01\" - For a year: \"2018\"  For a range period: -  Date range: \"2018-01-01/2018-01-15\" . [optional]
+                period (str): Period must have one of the following formats:  - For a day : \"2018-01-01\", - For a week: \"2018-W01\",  - For a month: \"2018-01\" - For a year: \"2018\" For a range period:  -  Date range: \"2018-01-01/2018-01-15\" . [optional]
                 current_page (int): Choose the number of search results to return per page. Minimum value: 1. [optional] if omitted the server will use the default value of 1
                 page_size (int): Results per page. Allowed values 1-100, default is 25.. [optional] if omitted the server will use the default value of 25
                 _return_http_data_only (bool): response data without head status
@@ -335,8 +336,8 @@ class RawStatisticsApi(_EndPoint):
                 video_id (str): The unique identifier for the video you want to retrieve session information for.
 
             Keyword Args:
-                period (str): Period must have one of the following formats:  - For a day : 2018-01-01, - For a week: 2018-W01, - For a month: 2018-01 - For a year: 2018  For a range period: -  Date range: 2018-01-01/2018-01-15 . [optional]
-                metadata ({str: (str,)}): Metadata and Dynamic Metadata filter. Send an array of key value pairs you want to filter sessios with.. [optional]
+                period (str): Period must have one of the following formats:  - For a day : 2018-01-01, - For a week: 2018-W01,  - For a month: 2018-01 - For a year: 2018 For a range period:  -  Date range: 2018-01-01/2018-01-15 . [optional]
+                metadata ({str: (str,)}): Metadata and [Dynamic Metadata](https://api.video/blog/endpoints/dynamic-metadata) filter. Send an array of key value pairs you want to filter sessios with.. [optional]
                 current_page (int): Choose the number of search results to return per page. Minimum value: 1. [optional] if omitted the server will use the default value of 1
                 page_size (int): Results per page. Allowed values 1-100, default is 25.. [optional] if omitted the server will use the default value of 25
                 _return_http_data_only (bool): response data without head status
