@@ -391,7 +391,7 @@ class Configuration(object):
                "OS: {env}\n"\
                "Python Version: {pyversion}\n"\
                "Version of the API: 1\n"\
-               "SDK Package Version: 0.0.14".\
+               "SDK Package Version: 0.0.17".\
                format(env=sys.platform, pyversion=sys.version)
 
     def get_host_settings(self):
@@ -402,7 +402,11 @@ class Configuration(object):
         return [
             {
                 'url': "https://ws.api.video",
-                'description': "No description provided",
+                'description': "Production server",
+            },
+            {
+                'url': "https://sandbox.api.video",
+                'description': "Test server `all videos are watermarked, and deleted after 24 hours.",
             }
         ]
 
